Crate pnets

PNETS

Pnets is a framework for manipulating Petri nets

This crate provides an api for manipulating Petri nets. Two main structures are provided by this library:

  • standard::Net - which allows to manipulate classical Petri net;
  • timed::Net - which allows the manipulation of temporal Petri net.

In order to easily manipulate these nets this api provides the following elements:

  • arc::Kind - an enum of the different types of arcs that exist in a Petri net;
  • Marking - a structure for manipulating hollow vectors;
  • PlaceId and TransitionId - a type for indexing places and transitions in networks.

Modules

  • Arcs which are supported by this framework
  • Standard Petri net
  • Network with time support

Structs

  • Hollow usize vector sorted with generic indices
  • Represent a place identifier in the network
  • Represent a transition identifier in the network

Enums

  • Errors generated when manipulating a Petri net
  • Represent an id in the network