pnets::timed

Struct Net

pub struct Net {
    pub name: String,
    pub transitions: IndexVec<TransitionId, Transition>,
    pub places: IndexVec<PlaceId, Place>,
    /* private fields */
}
Timed Petri net, with produce, consume, condition and inhibitors arcs

This structure is indexed with PlaceId and TransitionId to allow easy access to places and transitions.

As this kind of network is a superset of standard Petri net, we can create one from standard Petri net without loosing any informations.

Fields

name: String

Name of this network

transitions: IndexVec<TransitionId, Transition>

Transitions of the network

places: IndexVec<PlaceId, Place>

Places of the network

Implementations

Source

impl Net

pub fn create_place(&mut self) -> PlaceId

Create a place with automatic name

pub fn create_transition(&mut self) -> TransitionId

Create a transition with an empty name

pub fn get_name_by_index(&self, index: &NodeId) -> Option<String>

Get node name with its id

pub fn get_index_by_name(&self, name: &str) -> Option<NodeId>

Get node id with its name

pub fn rename_node(&mut self, id: NodeId, name: &str) -> Result<(), NetError>

Rename node

pub fn add_arc(&mut self, arc: Kind) -> Result<(), Box<dyn Error>>

Add an arc in the network. This kind of network support only arc::Kind::Consume, arc::Kind::Produce, arc::Kind::Inhibitor and arc::Kind::Test arcs.

Errors

Return NetError::UnsupportedArc when trying to add a kind of arc which is not supported

pub fn delete_place(&mut self, place: PlaceId)

Disconnect a place in the network

The place is not really deleted to avoid memory relocation and extra information about this place such as name can be useful later.

pub fn delete_transition(&mut self, transition: TransitionId)

Disconnect a transition in the network

The transition is not really deleted to avoid memory relocation and extra information about this transitions such as name can be useful later.

pub fn add_priority(&mut self, tr_index: TransitionId, over: TransitionId)

Add a priority relation in the network

pub fn update_priorities(&mut self) -> Result<(), Box<dyn Error>>

Update all priorities to make a transitive closure

Errors

NetError::CyclicPriorities is returned if there is a cyclic priority in the network